@@ -1,6 +1,12 @@
-"Main interface for guardduty service type defs"
-from __future__ import annotations
+"""
+Main interface for guardduty service type definitions.
 
+Usage::
+
+    from mypy_boto3.guardduty.type_defs import AccountDetailTypeDef
+
+    data: AccountDetailTypeDef = {...}
+"""
 import sys
 from typing import Dict, List
 
@@ -14,6 +20,82 @@ else:
     from typing_extensions import TypedDict
 
 
+__all__ = (
+    "AccountDetailTypeDef",
+    "CreateDetectorResponseTypeDef",
+    "CreateFilterResponseTypeDef",
+    "CreateIPSetResponseTypeDef",
+    "UnprocessedAccountTypeDef",
+    "CreateMembersResponseTypeDef",
+    "CreatePublishingDestinationResponseTypeDef",
+    "CreateThreatIntelSetResponseTypeDef",
+    "DeclineInvitationsResponseTypeDef",
+    "DeleteInvitationsResponseTypeDef",
+    "DeleteMembersResponseTypeDef",
+    "DestinationPropertiesTypeDef",
+    "DescribePublishingDestinationResponseTypeDef",
+    "DisassociateMembersResponseTypeDef",
+    "ConditionTypeDef",
+    "FindingCriteriaTypeDef",
+    "GetDetectorResponseTypeDef",
+    "GetFilterResponseTypeDef",
+    "AccessKeyDetailsTypeDef",
+    "IamInstanceProfileTypeDef",
+    "PrivateIpAddressDetailsTypeDef",
+    "SecurityGroupTypeDef",
+    "NetworkInterfaceTypeDef",
+    "ProductCodeTypeDef",
+    "TagTypeDef",
+    "InstanceDetailsTypeDef",
+    "ResourceTypeDef",
+    "DomainDetailsTypeDef",
+    "CityTypeDef",
+    "CountryTypeDef",
+    "GeoLocationTypeDef",
+    "OrganizationTypeDef",
+    "RemoteIpDetailsTypeDef",
+    "AwsApiCallActionTypeDef",
+    "DnsRequestActionTypeDef",
+    "LocalIpDetailsTypeDef",
+    "LocalPortDetailsTypeDef",
+    "RemotePortDetailsTypeDef",
+    "NetworkConnectionActionTypeDef",
+    "PortProbeDetailTypeDef",
+    "PortProbeActionTypeDef",
+    "ActionTypeDef",
+    "ThreatIntelligenceDetailTypeDef",
+    "EvidenceTypeDef",
+    "ServiceTypeDef",
+    "FindingTypeDef",
+    "GetFindingsResponseTypeDef",
+    "FindingStatisticsTypeDef",
+    "GetFindingsStatisticsResponseTypeDef",
+    "GetIPSetResponseTypeDef",
+    "GetInvitationsCountResponseTypeDef",
+    "MasterTypeDef",
+    "GetMasterAccountResponseTypeDef",
+    "MemberTypeDef",
+    "GetMembersResponseTypeDef",
+    "GetThreatIntelSetResponseTypeDef",
+    "InviteMembersResponseTypeDef",
+    "ListDetectorsResponseTypeDef",
+    "ListFiltersResponseTypeDef",
+    "ListFindingsResponseTypeDef",
+    "ListIPSetsResponseTypeDef",
+    "InvitationTypeDef",
+    "ListInvitationsResponseTypeDef",
+    "ListMembersResponseTypeDef",
+    "DestinationTypeDef",
+    "ListPublishingDestinationsResponseTypeDef",
+    "ListTagsForResourceResponseTypeDef",
+    "ListThreatIntelSetsResponseTypeDef",
+    "PaginatorConfigTypeDef",
+    "SortCriteriaTypeDef",
+    "StartMonitoringMembersResponseTypeDef",
+    "StopMonitoringMembersResponseTypeDef",
+    "UpdateFilterResponseTypeDef",
+)
+
 AccountDetailTypeDef = TypedDict("AccountDetailTypeDef", {"AccountId": str, "Email": str})
 
 CreateDetectorResponseTypeDef = TypedDict(
@@ -187,6 +269,7 @@ InstanceDetailsTypeDef = TypedDict(
         "InstanceId": str,
         "InstanceState": str,
         "InstanceType": str,
+        "OutpostArn": str,
         "LaunchTime": str,
         "NetworkInterfaces": List[NetworkInterfaceTypeDef],
         "Platform": str,
@@ -244,6 +327,8 @@ AwsApiCallActionTypeDef = TypedDict(
 
 DnsRequestActionTypeDef = TypedDict("DnsRequestActionTypeDef", {"Domain": str}, total=False)
 
+LocalIpDetailsTypeDef = TypedDict("LocalIpDetailsTypeDef", {"IpAddressV4": str}, total=False)
+
 LocalPortDetailsTypeDef = TypedDict(
     "LocalPortDetailsTypeDef", {"Port": int, "PortName": str}, total=False
 )
@@ -259,6 +344,7 @@ NetworkConnectionActionTypeDef = TypedDict(
         "ConnectionDirection": str,
         "LocalPortDetails": LocalPortDetailsTypeDef,
         "Protocol": str,
+        "LocalIpDetails": LocalIpDetailsTypeDef,
         "RemoteIpDetails": RemoteIpDetailsTypeDef,
         "RemotePortDetails": RemotePortDetailsTypeDef,
     },
@@ -267,7 +353,11 @@ NetworkConnectionActionTypeDef = TypedDict(
 
 PortProbeDetailTypeDef = TypedDict(
     "PortProbeDetailTypeDef",
-    {"LocalPortDetails": LocalPortDetailsTypeDef, "RemoteIpDetails": RemoteIpDetailsTypeDef},
+    {
+        "LocalPortDetails": LocalPortDetailsTypeDef,
+        "LocalIpDetails": LocalIpDetailsTypeDef,
+        "RemoteIpDetails": RemoteIpDetailsTypeDef,
+    },
     total=False,
 )
 
